translate.search.indexing.PyLuceneIndexer1

Package translate :: Package search :: Package indexing :: Module PyLuceneIndexer1 |
[hide private]
[frames] | no frames]

# Module PyLuceneIndexer1

source code

interface for the pylucene (v1.x) indexing engine

take a look at PyLuceneIndexer.py for PyLucene v2.x support

Classes | [hide private]
| PyLuceneDatabase manage and use a pylucene indexing database

Functions | [hide private]
is_available() | source code

Variables | [hide private]
| __revision__ = `"$Id: PyLuceneIndexer1.py 8505 2008-09-27 09:08`...``

Imports: PyLuceneIndexer, PyLucene

Variables Details | [hide private]

  ### __revision__ Value:
      "$Id: PyLuceneIndexer1.py 8505 2008-09-27 09:08:34Z dwaynebailey $"